Reference Guide
===============

.. toctree::
   :maxdepth: 4

   architecture
   fabulist_package

.. genindex fails when an epub is created with Sphinx 1.5
   Sphinx 1.6 is not yet supported by RTD
   genindex
